/*
 * Copyright 2016 by Kappich Systemberatung Aachen
 * 
 * This file is part of de.bsvrz.dua.tests.
 * 
 * de.bsvrz.dua.tests is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * de.bsvrz.dua.tests is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with de.bsvrz.dua.tests.  If not, see <http://www.gnu.org/licenses/>.

 * Contact Information:
 * Kappich Systemberatung
 * Martin-Luther-Straße 14
 * 52062 Aachen, Germany
 * phone: +49 241 4090 436 
 * mail: <info@kappich.de>
 */

package de.bsvrz.dua.tests;

import com.google.common.collect.ImmutableList;
import de.bsvrz.dav.daf.main.DataDescription;
import de.bsvrz.dav.daf.main.config.Aspect;
import de.bsvrz.dav.daf.main.config.AttributeGroup;

import java.util.Iterator;
import java.util.List;

/**
 * TBD Dokumentation
 *
 * @author Kappich Systemberatung
 */
public final class ComplexDataDescription implements Iterable<DataDescription> {
	private final List<AttributeGroup> _attributeGroups;
	private final Aspect _aspect;

	public ComplexDataDescription(final List<AttributeGroup> attributeGroups, final Aspect aspect) {
		_attributeGroups = ImmutableList.copyOf(attributeGroups);
		_aspect = aspect;
	}

	public ComplexDataDescription(final DataDescription dataDescription) {
		_attributeGroups = ImmutableList.of(dataDescription.getAttributeGroup());
		_aspect = dataDescription.getAspect();
	}
	public ComplexDataDescription(final ComplexDataDescription dataDescription) {
		_attributeGroups = dataDescription.getAttributeGroups();
		_aspect = dataDescription.getAspect();
	}

	public List<AttributeGroup> getAttributeGroups() {
		return _attributeGroups;
	}

	public Aspect getAspect() {
		return _aspect;
	}

	@Override
	public Iterator<DataDescription> iterator() {
		return _attributeGroups.stream().map(attributeGroup -> new DataDescription(attributeGroup, _aspect)).iterator();
	}

	@Override
	public boolean equals(final Object o) {
		if(this == o) return true;
		if(!(o instanceof ComplexDataDescription)) return false;

		final ComplexDataDescription that = (ComplexDataDescription) o;

		if(_attributeGroups != null ? !_attributeGroups.equals(that._attributeGroups) : that._attributeGroups != null) return false;
		return _aspect != null ? _aspect.equals(that._aspect) : that._aspect == null;

	}

	@Override
	public int hashCode() {
		int result = _attributeGroups != null ? _attributeGroups.hashCode() : 0;
		result = 31 * result + (_aspect != null ? _aspect.hashCode() : 0);
		return result;
	}
}
